@@ -1,25 +1,42 @@
+#
+# This file is part of Pod-Browser
+#
+# This software is Copyright (c) 2012 by Moritz Onken.
+#
+# This is free software, licensed under:
+#
+#   The (three-clause) BSD License
+#
 package Pod::Browser;
+{
+  $Pod::Browser::VERSION = '1.0.0';
+}
 use strict;
 use warnings;
-
+# ABSTRACT: Pod Web Server based on Catalyst and ExtJS
 use Catalyst::Runtime '5.70';
-
-use parent qw/Catalyst/;
-
-our $VERSION = '0.04';
+use base qw/Catalyst/;
 
 __PACKAGE__->config( name => 'Pod::Browser' );
-
 __PACKAGE__->setup(qw/ ConfigLoader Static::Simple/);
 
+sub { __PACKAGE__->run( @_) }
+
+
+
+=pod
 
 =head1 NAME
 
 Pod::Browser - Pod Web Server based on Catalyst and ExtJS
 
+=head1 VERSION
+
+version 1.0.0
+
 =head1 SYNOPSIS
 
-  # pod_browser_server.pl
+  # pod_browser
 
   visit http://localhost:3030
 
@@ -35,13 +52,9 @@ not installed this controller fetches the source code from CPAN and creates the
 There is also a TOC which is always visible and scrolls the current POD to the selected section.
 
 It is written using a JavaScript framework called ExtJS (L<http://www.extjs.com>) which
-generate beautiful and intuitive interfaces.
+generates beautiful and rich user interfaces.
 
-Have a look at L<http://cpan.org/authors/id/P/PE/PERLER/pod-images/pod-encyclopedia-01.png>
-
-=head1 NOTICE
-
-This is the second release. There are probably a lot of bugs.
+=for html <p><center><img src="http://cpan.org/authors/id/P/PE/PERLER/pod-images/pod-encyclopedia-01.png" width="882" height="462" /></center></p>
 
 =head1 CONFIGURATION
 
@@ -69,7 +82,6 @@ Defaults to C<["*"]>
 
 Search for modules in C<< $c->path_to( 'lib' ) >>.
 
-
 Defaults to C<1>.
 
 =item dirs (Arrayref)
@@ -82,32 +94,10 @@ Defaults to C<[]>.
 
 =head1 STARTING THE SERVER
 
-The server backend is a Catalyst application which gives you the choice how you want to run the server.
+C<pod_browser> makes use of L<Plack::Runner>. As a result, all options from L<plackup> are
+also available to C<pod_browser>.
 
-=head2 Catalyst Development Server
-
-The easiest way might be to start the server by running
-  pod_browser_server.pl
-
-This is the Catalyst development server but should be suffient for testing or usage by a limited number
-of users.
-
-=head2 FastCGI
-
-For better performance you can chose the FastCGI server. See L<Catalyst::Manual::Cookbook/"FastCGI Deployment">
-on how to set this up.
-
-=head2 More Engines
-
-There are many more Catalyst engines avaiable. Another interesting Engine might be L<Catalyst::Engine::Apache2>.
-Check out the Catalyst::Engine namespace and see L<Catalyst::Manual::Cookbook/Deployment>.
-
-=head1 BUGS
-
-=head2 Jump to sections
-
-There are some names of sections in some Pods which include special characters. There are still some problems with them.
-It would be helpful if you report these Pods so I can work around these cases.
+Run C<pod_browser --help> or see L<plackup> for more information.
 
 =head1 INTEGRATION IN CATALYST
 
@@ -126,11 +116,18 @@ L<Pod::Server>, L<Pod::Webserver>, L<Pod::POM::Web>
 
 =head1 AUTHOR
 
-Moritz Onken
+Moritz Onken <onken@netcubed.de>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software, you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is Copyright (c) 2012 by Moritz Onken.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
+
+
+__END__
 
-=cut
\ No newline at end of file
